Paper class

Constructors

Paper(int id, String name, double width, double height)

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
id int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited